"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_syntax_highlighter_1 = require("react-syntax-highlighter");
const CleanDataParser = (block, index) => {
    console.log(block);
    switch (block.type) {
        case 'header':
            switch (block.data.level) {
                case 1: return react_1.default.createElement("h1", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                case 2: return react_1.default.createElement("h2", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                case 3: return react_1.default.createElement("h3", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                case 4: return react_1.default.createElement("h4", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                case 5: return react_1.default.createElement("h5", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                case 6: return react_1.default.createElement("h6", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
                default: return react_1.default.createElement("p", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
            }
        case 'paragraph':
            return react_1.default.createElement("p", { key: index, dangerouslySetInnerHTML: { __html: block.data.text } });
        case 'delimiter':
            return react_1.default.createElement("hr", { key: index });
        case 'image':
            return react_1.default.createElement("img", { key: index, alt: block.data.caption, className: "img-fluid", src: block.data.file && block.data.file.url, title: block.data.caption });
        case 'list':
            if (!Array.isArray(block.data.items)) {
                console.warn('Failed to parse `list` without `items`.\nBlock:', block);
                return null;
            }
            switch (block.data.style) {
                case 'ordered': {
                    return (react_1.default.createElement("ol", { key: index }, block.data.items.map((li, idx) => {
                        return react_1.default.createElement("li", { key: `${li}-${idx}-item`, dangerouslySetInnerHTML: { __html: li } });
                    })));
                }
                default: {
                    return (react_1.default.createElement("ul", { key: index }, block.data.items.map((li, idx) => {
                        return react_1.default.createElement("li", { key: `${li}-${idx}-item`, dangerouslySetInnerHTML: { __html: li } });
                    })));
                }
            }
        case 'code':
            return (react_1.default.createElement(react_syntax_highlighter_1.Prism, { language: 'typescript', key: index }, block.data.code));
        case 'quote': {
            return react_1.default.createElement("blockquote", { key: index },
                " ",
                react_1.default.createElement("p", { dangerouslySetInnerHTML: { __html: block.data.text } }));
        }
        case 'raw': {
            if (!block.data.html) {
                console.warn('Failed to parse `raw` without `html`.\nBlock:', block);
                return null;
            }
            return (react_1.default.createElement("div", { key: index, dangerouslySetInnerHTML: { __html: block.data.html } }));
        }
        default:
            console.log('Unknown block type', block.type);
            console.log(block);
            return null;
    }
};
exports.default = CleanDataParser;
//# sourceMappingURL=index.js.map